@@ -1,5 +1,5 @@
 sp.associated.idx <-
-function(sp_gene_expr,z_thre=1.5,FPKM_thre=1){
+function(sp_gene_expr,z_thre=1.5){
   sp.std <- function(sp_gene_expr){
     cbind(sp_gene_expr[,1], t(apply(sp_gene_expr[,2:ncol(sp_gene_expr)], 1, FUN=function(x) {
       x <- as.numeric(x)
@@ -8,5 +8,5 @@ function(sp_gene_expr,z_thre=1.5,FPKM_thre=1){
   }
   sp_z=sp.std(sp_gene_expr)
   sapply(2:ncol(sp_z), FUN=function(i) 
-  which(sp_z[,i]>z_thre & sp_gene_expr[,i]>FPKM_thre), simplify=FALSE)  
+  which(sp_z[,i]>z_thre & rowSums(sp_gene_expr[,2:ncol(sp_gene_expr)])>0), simplify=FALSE)  
 }
